# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

"""CI Automation: mojo helpers."""

import os
import subprocess

from . import utils


SERIES = 'trusty'


def project_exists(project):
    '''Check the provided mojo project exists.'''
    args = [
        'mojo',
        'project-list',
        '-n',
    ]
    out = subprocess.check_output(args)

    if project in out.decode('utf8').split('\n'):
        return True
    else:
        return False


def new_workspace(project, stage, spec_branch, name):
    '''Create a fresh mojo workspace for the given project'''
    args = [
        'mojo',
        'workspace-new',
        '--project', project,
        '--stage={}'.format(stage),
        '--series', SERIES,
        spec_branch,
        name,
    ]
    utils.check_call(args)


def deploy(project, stage, spec_branch, juju_home):
    '''Deploy the given mojo project.'''
    workspace_name = os.path.basename(juju_home)
    env = os.environ.copy()
    env['JUJU_HOME'] = juju_home

    # Run juju status before trying to deploy as a safe workaround
    # (https://bugs.launchpad.net/juju-deployer/+bug/1368403)
    args = ['juju', 'status']
    utils.check_call(args, env=env)

    args = [
        'mojo',
        'run',
        '--project', project,
        '--series', SERIES,
        '--stage', stage,
        spec_branch,
        workspace_name,
    ]

    utils.check_call(args, env=env)


def workspace_destroy(project, name):
    args = ['mojo', 'workspace-destroy', '--project', project, '--ffs', name]
    try:
        subprocess.check_call(args,
                              stdout=subprocess.DEVNULL,
                              stderr=subprocess.DEVNULL)
    except subprocess.CalledProcessError:
        # No mojo workspace with this name
        pass
