#!/usr/bin/env python3
#
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
"""CI Automation: script for listing auto-deployed services."""

import argparse
import datetime
import os
import sys


from ci_automation.nova import get_services_map
from ci_automation.utils import setup_logger


def main():
    parser = argparse.ArgumentParser(
        description="Check the number of deployments for a service")
    parser.add_argument('--base-dir', '-b',
                        default=os.path.expanduser("~/ci-cd-identifiers"),
                        help="The directory where identifiers are stored "
                             " (eg. ~/ci-cd-identifiers)")
    args = parser.parse_args()
    logger = setup_logger()

    services = get_services_map(args.base_dir)
    sorted_services = sorted(services.items(), key=lambda s: s[0])
    for srv, deployments in sorted_services:
        print('* {}:'.format(srv))
        sorted_deployments = sorted(
            deployments.items(), key=lambda d: d[1]['epoch'], reverse=True)
        for ident, contents in sorted_deployments:
            date_created = datetime.datetime.utcfromtimestamp(
                contents['epoch']).ctime()
            float_ips = ""
            if contents['floating_ips']:
                float_ips = "=> {}".format(', '.join(
                    contents['floating_ips']))
            print('\t{}: {} ({} units) {}'.format(
                ident, date_created, len(contents['units']), float_ips))

    return 0


if __name__ == "__main__":
    sys.exit(main())
