#!/usr/bin/env python3
#
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
"""CI Automation: monitoring (purging obsolete deployments) services."""

import argparse
import os
import sys


from ci_automation.nova import get_services_map
from ci_automation.utils import setup_logger


def main():
    parser = argparse.ArgumentParser(
        description="Check the number of deployments for a service")
    parser.add_argument(
        '--base-dir', '-b',
        default=os.path.expanduser("~/ci-cd-identifiers"),
        help="The directory where identifiers are stored "
        " (eg. ~/ci-cd-identifiers)")
    parser.add_argument(
        '--max-deployments', '-m', type=int, default=2,
        help="The maximum number of deployments to keep.")
    parser.add_argument(
        'stage_dirname',
        help="the mojo stage directory name (eg. mojo-ue-core-image-tester")

    args = parser.parse_args()
    logger = setup_logger()

    deployments = get_services_map(args.base_dir).get(args.stage_dirname)
    if deployments is None:
        print('No deployments found!')
        return

    sorted_deployments = sorted(
        deployments.items(), key=lambda d: d[1]['epoch'], reverse=True)
    for identifier, _ in sorted_deployments[args.max_deployments:]:
        extra = {
            "service": "ci/cd",
            "deployment_status": "DESTROYED",
            "deployment_name": args.stage_dirname,
            "deployment_identifier": identifier,
        }
        logger.info(
            "Destroying deployment %s", identifier, extra=extra)

    return 0


if __name__ == "__main__":
    sys.exit(main())
