#!/usr/bin/env python3
#
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
"""CI Automation: tool for monitoring rabbitmq queue information."""

import argparse
import json
import os
import subprocess

from ci_automation.utils import setup_logger


# Depends on having 'rabbitmqadmin' CLI downloaded to the ~ubuntu/ on
# the server.
REMOTE_CMD = (
    '/home/ubuntu/rabbitmqadmin list queues '
    'name messages messages_unacknowledged consumers'
)


def main():
    parser = argparse.ArgumentParser(
        description="Monitor queue of a given rabbit server.")
    parser.add_argument(
        'host', metavar="RABBITMQ_HOST",
        help="Rabbitmq host to monitor"
    )

    args = parser.parse_args()
    logger = setup_logger()

    remote_cmd = REMOTE_CMD
    if os.environ.get('CI_LOGSTASH_HOST') is not None:
        remote_cmd += ' --format=raw_json'

    args = [
        'ssh',
        'ubuntu@{}'.format(args.host),
        remote_cmd,
    ]
    output = subprocess.check_output(args)

    if os.environ.get('CI_LOGSTASH_HOST') is not None:
        queues = json.loads(output.decode('utf-8'))
        for queue in queues:
            extra = {
                'service': 'queue-monitor',
            }
            queue['queue'] = queue.pop('name')
            extra.update(queue)
            logger.info('Recorded info about {}'.format(queue['queue']),
                        extra=extra)
    else:
        print(output.decode('utf-8'))


if __name__ == '__main__':
    main()
