#!/usr/bin/env python3
#
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
"""CI Automation: Destroys an environment upon given its SHA1 value."""

import argparse
import glob
import os
import sys


from ci_automation import (
    juju,
    mojo,
    swift,
)


def main():
    parser = argparse.ArgumentParser(
        description=('Destroys the juju environment of a given identifier')
    )
    parser.add_argument('--project', default='mojo-stg-ue-ci-engineering')
    parser.add_argument('--base',
                        default=os.path.expanduser('~/juju-environments/'))
    parser.add_argument('identifier', metavar='IDENTIFIER')
    args = parser.parse_args()

    glob_pattern = os.path.join(args.base, '*{}'.format(args.identifier))
    matching = glob.glob(glob_pattern)
    if not matching:
        print("Nothing to do - no files matching pattern %r" % glob_pattern)
        # We are happy if it's already destroyed.
        return 0

    try:
        [env_dir] = matching
    except ValueError:
        print('Environments collision ? %r', matching)
        return 1

    name = os.path.basename(env_dir)
    if juju.deployment_has_floating_ips(name, args.base):
        print("""\
Cowardly refusing to reap that, since it has floating IP addresses assigned.

Don't do what Thomi did and destroy in-use production services!
Assign all floating IP addresses to a new deployment, then call reaper.py
again.
        """)
        return 1

    juju.destroy_all_services(name, args.base)
    print('Services destroyed')
    juju.destroy_environment(name, args.base)
    print('Environment {} destroyed'.format(name))
    control_bucket = "juju-{}".format(name)
    swift.delete(control_bucket)
    print('Swift control bucket {} deleted'.format(control_bucket))
    mojo.workspace_destroy(args.project, name)
    print('Mojo Workspace {}/{} destroyed'.format(args.project, name))

    return 0


if __name__ == '__main__':
    sys.exit(main())
